@@ -2,6 +2,7 @@ import base64
 import hashlib
 import json
 import requests
+import ecdsa
 
 import cyberpy.interfaces.tx_pb2 as tx
 import cyberpy.interfaces.msg_send_pb2 as transfer
@@ -10,10 +11,6 @@ import cyberpy.interfaces.pubkey_pb2 as pubkey
 import cyberpy.interfaces.msg_link_pb2 as MsgCyberlink
 
 from cyberpy.interfaces.any_pb2 import Any
-
-
-import ecdsa
-
 from cyberpy._wallet import privkey_to_address, privkey_to_pubkey
 from cyberpy._typing import SyncMode
 
@@ -38,7 +35,7 @@ class Transaction:
         gas: int,
         fee_denom: str = "boot",
         memo: str = "",
-        chain_id: str = "bostrom-testnet-1",
+        chain_id: str = "bostrom-testnet-4",
         sync_mode: SyncMode = "broadcast_tx_commit",
     ) -> None:
         self._raw_tx = tx.TxRaw()
@@ -78,6 +75,19 @@ class Transaction:
         msg_link_any.type_url = '/cyber.graph.v1beta1.MsgCyberlink'
         self._tx_body.messages.append(msg_link_any)
 
+    def add_chain_cyberlink(self, chainlink: list) -> None:
+        msg_link = MsgCyberlink.MsgCyberlink()
+        msg_link.address = privkey_to_address(self._privkey)
+        for cyberlink in chainlink:
+            links = MsgCyberlink.Link()
+            links.__setattr__('from', cyberlink[0])
+            links.__setattr__('to', cyberlink[1])
+            msg_link.links.append(links)
+        msg_link_any = Any()
+        msg_link_any.Pack(msg_link)
+        msg_link_any.type_url = '/cyber.graph.v1beta1.MsgCyberlink'
+        self._tx_body.messages.append(msg_link_any)
+
     def get_pushable(self):
         self._raw_tx.body_bytes = self._tx_body.SerializeToString()
         self._raw_tx.auth_info_bytes = self._get_auth_info().SerializeToString()
